pub struct RecoveryUpdateConfig {
pub channel: String,
pub update_type: UpdateType,
pub version: String,
}Fields
channel: Stringupdate_type: UpdateTypeversion: StringImplementations
Sourceimpl RecoveryUpdateConfig
impl RecoveryUpdateConfig
Sourcepub async fn resolve_update_config() -> Result<RecoveryUpdateConfig, Error>
pub async fn resolve_update_config() -> Result<RecoveryUpdateConfig, Error>
Resolve the update configuration using values from vbmeta (via boot args), the build-provided json config, and the current version from BuildInfo.