pub struct OtaEnvBuilder { /* private fields */ }Expand description
Helper for constructing OTAs.
Implementations
Sourceimpl OtaEnvBuilder
impl OtaEnvBuilder
Sourcepub fn new(outgoing_dir: Arc<Simple>) -> Self
pub fn new(outgoing_dir: Arc<Simple>) -> Self
Create a new OtaEnvBuilder. Requires an outgoing_dir which is served
by an instantiation of a Rust VFS tied to this component’s outgoing
directory. This is required in order to prepare the outgoing directory
with capabilities like directories and storage for the pkg-recovery.cm
component which will be created as a child.
Sourcepub fn devhost(self, cfg: DevhostConfig) -> Self
pub fn devhost(self, cfg: DevhostConfig) -> Self
Use the given |DevhostConfig| to run an OTA.
Sourcepub fn omaha_config(self, omaha_config: OmahaConfig) -> Self
pub fn omaha_config(self, omaha_config: OmahaConfig) -> Self
Use the given |OmahaConfig| to run an OTA.
Sourcepub fn blobfs_proxy(self, blobfs_proxy: DirectoryProxy) -> Self
pub fn blobfs_proxy(self, blobfs_proxy: DirectoryProxy) -> Self
Use the given StorageType as the storage target.